<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>AppPreferences</name>
    <message>
        <source>&amp;Preferences</source>
        <translation type="obsolete">&amp;Preferenze</translation>
    </message>
    <message>
        <location filename="../AppPreferences.js" line="+65"/>
        <source>Application &amp;Preferences</source>
        <translation>Preferenze &amp;applicazione</translation>
    </message>
</context>
</TS>
